@@ -45,6 +45,7 @@ using TDERecentAddress::RecentAddresses;
 #include "kmsystemtray.h"
 #include "transportmanager.h"
 #include "importarchivedialog.h"
+#include <mimelib/enum.h>
 
 #include <twin.h>
 #include "kmailicalifaceimpl.h"
@@ -574,7 +575,7 @@ int KMKernel::openComposer (const TQString &to, const TQString &cc,
        if( ! GlobalSettings::self()->exchangeCompatibleInvitations() ) {
         msgPart->setContentDisposition( attachContDisp );
       }
-      if( !attachCharset.isEmpty() ) {
+      if( !attachCharset.isEmpty() && (msgPart->type() == DwMime::kTypeText) ) {
         // kdDebug(5006) << "KMKernel::openComposer set attachCharset to "
         // << attachCharset << endl;
         msgPart->setCharset( attachCharset );
