@@ -176,7 +176,7 @@ int main( int argc, char *argv[] )
     "(c) 2002-2005, Tuukka Pasanen and Allen Winter", // copyright statement
     0,                               // any free form text
     progURL,                         // program home page address
-    "bugs.kde.org"                   // bug report email address
+    "bugs.trinitydesktop.org"                   // bug report email address
     );
 
   aboutData.addAuthor(
