@@ -1932,9 +1932,6 @@ icaltimetype ICalFormatImpl::writeICalDate(const TQDate &date)
   t.second = 0;
 
   t.is_date = 1;
-
-  t.is_utc = 0;
-
   t.zone = 0;
 
   return t;
@@ -1954,7 +1951,6 @@ icaltimetype ICalFormatImpl::writeICalDateTime(const TQDateTime &datetime)
 
   t.is_date = 0;
   t.zone = icaltimezone_get_builtin_timezone ( mParent->timeZoneId().latin1() );
-  t.is_utc = 0;
 
  // _dumpIcaltime( t );
   /* The TQDateTime we get passed in is to be considered in the timezone of
@@ -1969,7 +1965,6 @@ icaltimetype ICalFormatImpl::writeICalDateTime(const TQDateTime &datetime)
       t.zone = tz;
       t = icaltime_convert_to_zone( t, utc );
     } else {
-      t.is_utc = 1;
       t.zone = utc;
     }
   }
@@ -1981,11 +1976,10 @@ icaltimetype ICalFormatImpl::writeICalDateTime(const TQDateTime &datetime)
 TQDateTime ICalFormatImpl::readICalDateTime( icalproperty *p, icaltimetype& t, icaltimezone* tz )
 {
 //   kdDebug(5800) << "ICalFormatImpl::readICalDateTime()" << endl;
-  if ( tz && t.is_utc == 0 ) { // Only use the TZ if time is not UTC.
+  if (tz && !icaltime_is_utc(t)) { // Only use the TZ if time is not UTC.
     // FIXME: We'll need to make sure to apply the appropriate TZ, not just
     //        the first one found.
-    t.is_utc = (tz == icaltimezone_get_utc_timezone())?1:0;
-    if (t.is_utc == 0) {
+    if (tz != icaltimezone_get_utc_timezone()) {
         icalparameter *param = p ? icalproperty_get_first_parameter(p, ICAL_TZID_PARAMETER) : 0;
         const char *tzid = param ? icalparameter_get_tzid(param) : 0;
         if ( !tzid )
